from __future__ import print_function
from __future__ import absolute_import
from __future__ import division

from OpenGL.GLUT import *
from OpenGL.GLU import *
from OpenGL.GL import *


__all__ = ['Arrow']


class Arrow(object):
    pass


# ==============================================================================
# Main
# ==============================================================================

if __name__ == '__main__':
    pass
